@@ -16,11 +16,13 @@
 from zope import interface
 from zope.browserpage.viewpagetemplatefile import ViewPageTemplateFile
 
-import zc.table.table
 import zc.table.interfaces
+import zc.table.table
+
 
 unspecified = object()
 
+
 class Formatter(zc.table.table.FormSortFormatterMixin,
                 zc.table.table.AlternatingRowFormatterMixin,
                 zc.table.table.Formatter):
@@ -35,11 +37,11 @@ class Formatter(zc.table.table.FormSortFormatterMixin,
         if prefix is None:
             prefix = 'zc.table'
 
-        super(Formatter, self).__init__(
+        super().__init__(
             context, request, items, visible_column_names,
             batch_start, batch_size, prefix, columns,
             sort_on=sort_on,
-            )
+        )
 
     @property
     def batch_change_name(self):
@@ -53,21 +55,23 @@ class Formatter(zc.table.table.FormSortFormatterMixin,
     _batch_start_computed = False
 
     def setPrefix(self, prefix):
-        super(Formatter, self).setPrefix(prefix)
+        super().setPrefix(prefix)
         self._batch_start_computed = False
 
-    @apply
-    def batch_start():
-        def fget(self):
-            if not self._batch_start_computed:
-                self.updateBatching()
-            return self._batch_start
-        def fset(self, value):
-            self._batch_start = value
-            self._batch_start_computed = False
-        def fdel(self):
-            self._batch_start = None
-        return property(fget, fset, fdel)
+    @property
+    def batch_start(self):
+        if not self._batch_start_computed:
+            self.updateBatching()
+        return self._batch_start
+
+    @batch_start.setter
+    def batch_start(self, value):
+        self._batch_start = value
+        self._batch_start_computed = False
+
+    @batch_start.deleter
+    def batch_start(self):
+        self._batch_start = None
 
     def updateBatching(self):
         request = self.request
@@ -108,10 +112,11 @@ class Formatter(zc.table.table.FormSortFormatterMixin,
         self._batch_start_computed = True
 
     batching_template = ViewPageTemplateFile('batching.pt')
+
     def renderExtra(self):
         if not self._batch_start_computed:
             self.updateBatching()
-        return self.batching_template() + super(Formatter, self).renderExtra()
+        return self.batching_template() + super().renderExtra()
 
     def __call__(self):
         return ('\n'
@@ -123,4 +128,4 @@ class Formatter(zc.table.table.FormSortFormatterMixin,
                 '</table>\n'
                 + self.renderExtra() +
                 '</div> <!-- end IE bug workaround -->\n'
-               )
+                )
