@@ -17,14 +17,16 @@ $Id: table.py 4428 2005-12-13 23:35:48Z gary $
 """
 from xml.sax.saxutils import quoteattr
 
-from zope import interface, component
+import zc.resourcelibrary
 import zope.cachedescriptors.property
+from zope import component
+from zope import interface
 
 from zc.table import interfaces
-import zc.resourcelibrary
 
-class Formatter(object):
-    interface.implements(interfaces.IFormatter)
+
+@interface.implementer(interfaces.IFormatter)
+class Formatter:
     items = None
 
     def __init__(self, context, request, items, visible_column_names=None,
@@ -63,7 +65,7 @@ class Formatter(object):
         return klass and ' class=%s' % quoteattr(klass) or ''
 
     def __call__(self):
-        return '\n<table%s>\n%s</table>\n%s' % (
+        return '\n<table{}>\n{}</table>\n{}'.format(
                 self._getCSSClass('table'), self.renderContents(),
                 self.renderExtra())
 
@@ -72,12 +74,12 @@ class Formatter(object):
         return ''
 
     def renderContents(self):
-        return '  <thead%s>\n%s  </thead>\n  <tbody>\n%s  </tbody>\n' % (
+        return '  <thead{}>\n{}  </thead>\n  <tbody>\n{}  </tbody>\n'.format(
                 self._getCSSClass('thead'), self.renderHeaderRow(),
                 self.renderRows())
 
     def renderHeaderRow(self):
-        return '    <tr%s>\n%s    </tr>\n' %(
+        return '    <tr{}>\n{}    </tr>\n'.format(
             self._getCSSClass('tr'), self.renderHeaders())
 
     def renderHeaders(self):
@@ -85,7 +87,7 @@ class Formatter(object):
             [self.renderHeader(col) for col in self.visible_columns])
 
     def renderHeader(self, column):
-        return '      <th%s>\n        %s\n      </th>\n' % (
+        return '      <th{}>\n        {}\n      </th>\n'.format(
             self._getCSSClass('th'), self.getHeader(column))
 
     def getHeaders(self):
@@ -103,7 +105,7 @@ class Formatter(object):
                    for column in self.visible_columns]
 
     def renderRow(self, item):
-        return '  <tr%s>\n%s  </tr>\n' % (
+        return '  <tr{}>\n{}  </tr>\n'.format(
             self._getCSSClass('tr'), self.renderCells(item))
 
     def renderCells(self, item):
@@ -111,8 +113,8 @@ class Formatter(object):
             [self.renderCell(item, col) for col in self.visible_columns])
 
     def renderCell(self, item, column):
-        return '    <td%s>\n      %s\n    </td>\n' % (
-            self._getCSSClass('td'), self.getCell(item, column),)
+        return '    <td{}>\n      {}\n    </td>\n'.format(
+            self._getCSSClass('td'), self.getCell(item, column))
 
     def getCells(self, item):
         return [self.getCell(item, column) for column in self.visible_columns]
@@ -124,26 +126,28 @@ class Formatter(object):
         batch_start = self.batch_start or 0
         batch_size = self.batch_size or 0
         if not self.batch_size:
-            if not batch_start: # ok, no work to be done.
+            if not batch_start:  # ok, no work to be done.
                 for i in self.items:
                     yield i
-                raise StopIteration
+                return
             batch_end = None
         else:
             batch_end = batch_start + batch_size
         try:
             for i in self.items[batch_start:batch_end]:
                 yield i
-        except (AttributeError, TypeError):
+        except (AttributeError, TypeError, NotImplementedError):
             for i, item in enumerate(self.items):
                 if batch_end is not None and i >= batch_end:
                     return
                 if i >= batch_start:
                     yield item
 
+
 # sorting helpers
 
-class ColumnSortedItems(object):
+@interface.implementer(interfaces.IColumnSortedItems)
+class ColumnSortedItems:
     # not intended to be persistent!
     """a wrapper for items that sorts lazily based on ISortableColumns.
 
@@ -151,13 +155,12 @@ class ColumnSortedItems(object):
     with the primary sort column, and the formatter, supports iteration, len,
     and __getitem__ access including slices.
     """
-    interface.implements(interfaces.IColumnSortedItems)
 
     formatter = None
 
     def __init__(self, items, sort_on):
         self._items = items
-        self.sort_on = sort_on # tuple of (column name, reversed) pairs
+        self.sort_on = sort_on  # tuple of (column name, reversed) pairs
         self._cache = []
         self._iterable = None
 
@@ -179,9 +182,12 @@ class ColumnSortedItems(object):
             try:
                 yield cache[ix]
             except IndexError:
-                next = iterable.next() # let StopIteration fall through
-                cache.append(next)
-                yield next
+                try:
+                    nxt = next(iterable)
+                except StopIteration:
+                    return
+                cache.append(nxt)
+                yield nxt
             ix += 1
 
     def setFormatter(self, formatter):
@@ -213,7 +219,7 @@ class ColumnSortedItems(object):
                 return items.__getitem__(key)
             except (AttributeError, TypeError):
                 if stride != 1:
-                    raise NotImplemented
+                    raise NotImplementedError()
                 res = []
                 for ix, val in enumerate(items):
                     if ix >= start:
@@ -226,7 +232,7 @@ class ColumnSortedItems(object):
                 elif res:
                     return res[0]
                 else:
-                    raise IndexError, 'list index out of range'
+                    raise IndexError('list index out of range')
 
         items = self.sorters[0](
             items, self.formatter, start, stop, self.sorters[1:])
@@ -236,13 +242,15 @@ class ColumnSortedItems(object):
         else:
             return items[key]
 
-    def __nonzero__(self):
+    def __bool__(self):
         try:
-            iter(self.items).next()
+            next(iter(self.items))
         except StopIteration:
             return False
         return True
 
+    __nonzero__ = __bool__
+
     def __iter__(self):
         if not self.sort_on:
             return iter(self.items)
@@ -254,6 +262,7 @@ class ColumnSortedItems(object):
     def __len__(self):
         return len(self.items)
 
+
 def getRequestSortOn(request, sort_on_name):
     """get the sorting values from the request.
 
@@ -273,12 +282,11 @@ def getRequestSortOn(request, sort_on_name):
                 val[0] = ix + offset
                 val[2] = not val[2]
         if res:
-            res = res.values()
-            res.sort()
-            res.reverse()
+            res = sorted(res.values(), reverse=True)
             sort_on = [[nm, reverse] for ix, nm, reverse in res]
     return sort_on
 
+
 def getMungedSortOn(request, sort_on_name, sort_on):
     """get the sorting values from the request.
 
@@ -298,6 +306,7 @@ def getMungedSortOn(request, sort_on_name, sort_on):
                 res.append([nm, reverse])
     return res
 
+
 def getSortOnName(prefix=None):
     """convert the table prefix to the 'sort on' name used in forms"""
     # useful for code that wants to get the sort on values themselves
@@ -309,7 +318,7 @@ def getSortOnName(prefix=None):
     return sort_on_name
 
 
-class SortingFormatterMixin(object):
+class SortingFormatterMixin:
     """automatically munges sort_on values with sort settings in the request.
     """
 
@@ -323,7 +332,7 @@ class SortingFormatterMixin(object):
         if sort_on or getattr(items, '__getitem__', None) is None:
             items = ColumnSortedItems(items, sort_on)
 
-        super(SortingFormatterMixin, self).__init__(
+        super().__init__(
             context, request, items, visible_column_names,
             batch_start, batch_size, prefix, columns)
 
@@ -332,16 +341,17 @@ class SortingFormatterMixin(object):
 
     def setItems(self, items):
         if (interfaces.IColumnSortedItems.providedBy(self.items) and
-            not interfaces.IColumnSortedItems.providedBy(items)):
+                not interfaces.IColumnSortedItems.providedBy(items)):
             items = ColumnSortedItems(items, self.items.sort_on)
         if interfaces.IColumnSortedItems.providedBy(items):
             items.setFormatter(self)
         self.items = items
 
-class AbstractSortFormatterMixin(object):
+
+class AbstractSortFormatterMixin:
     """provides sorting UI: concrete classes must declare script_name."""
 
-    script_name = None # Must be defined in subclass
+    script_name = None  # Must be defined in subclass
 
     def getHeader(self, column):
         contents = column.renderHeader(self)
@@ -353,7 +363,7 @@ class AbstractSortFormatterMixin(object):
         columnName = column.name
         resource_path = component.getAdapter(self.request, name='zc.table')()
         if (interfaces.IColumnSortedItems.providedBy(self.items) and
-            self.items.sort_on):
+                self.items.sort_on):
             sortColumnName, sortReversed = self.items.sort_on[0]
         else:
             sortColumnName = sortReversed = None
@@ -382,12 +392,14 @@ class AbstractSortFormatterMixin(object):
             <span class="zc-table-sortable"
                   onclick="javascript: %(script_name)s(
                         '%(columnName)s', '%(sort_on_name)s')"
-                    onMouseOver="javascript: this.className='sortable zc-table-sortable'"
-                    onMouseOut="javascript: this.className='zc-table-sortable'">
+                  onMouseOver="javascript:
+                      this.className='sortable zc-table-sortable'"
+                  onMouseOut="javascript: this.className='zc-table-sortable'">
                 %(header)s</span> %(dirIndicator)s
         """
         return template % options
 
+
 class StandaloneSortFormatterMixin(AbstractSortFormatterMixin):
     "A version of the sort formatter mixin for standalone tables, not forms"
 
@@ -410,7 +422,7 @@ class FormSortFormatterMixin(AbstractSortFormatterMixin):
         if sort_on or getattr(items, '__getitem__', None) is None:
             items = ColumnSortedItems(items, sort_on)
 
-        super(FormSortFormatterMixin, self).__init__(
+        super().__init__(
             context, request, items, visible_column_names,
             batch_start, batch_size, prefix, columns)
 
@@ -422,7 +434,7 @@ class FormSortFormatterMixin(AbstractSortFormatterMixin):
     def renderExtra(self):
         """Render the hidden input field used to keep up with sorting"""
         if (interfaces.IColumnSortedItems.providedBy(self.items) and
-            self.items.sort_on):
+                self.items.sort_on):
             value = []
             for name, reverse in reversed(self.items.sort_on):
                 value.append(name)
@@ -433,33 +445,34 @@ class FormSortFormatterMixin(AbstractSortFormatterMixin):
             value = ''
 
         sort_on_name = getSortOnName(self.prefix)
-        return '<input type="hidden" name=%s id=%s value=%s />\n' % (
+        return '<input type="hidden" name={} id={} value={} />\n'.format(
             quoteattr(sort_on_name+":tokens"),
             quoteattr(sort_on_name),
             quoteattr(value)
-            ) + super(FormSortFormatterMixin, self).renderExtra()
+            ) + super().renderExtra()
 
     def setItems(self, items):
         if (interfaces.IColumnSortedItems.providedBy(self.items) and
-            not interfaces.IColumnSortedItems.providedBy(items)):
+                not interfaces.IColumnSortedItems.providedBy(items)):
             items = ColumnSortedItems(items, self.items.sort_on)
         if interfaces.IColumnSortedItems.providedBy(items):
             items.setFormatter(self)
         self.items = items
 
-class AlternatingRowFormatterMixin(object):
+
+class AlternatingRowFormatterMixin:
     row_classes = ('even', 'odd')
 
     def renderRows(self):
         self.row = 0
-        return super(AlternatingRowFormatterMixin, self).renderRows()
+        return super().renderRows()
 
     def renderRow(self, item):
         self.row += 1
         klass = self.cssClasses.get('tr', '')
         if klass:
             klass += ' '
-        return '  <tr class=%s>\n%s  </tr>\n' % (
+        return '  <tr class={}>\n{}  </tr>\n'.format(
             quoteattr(klass + self.row_classes[self.row % 2]),
             self.renderCells(item))
 
@@ -469,21 +482,26 @@ class AlternatingRowFormatterMixin(object):
 class SortingFormatter(SortingFormatterMixin, Formatter):
     pass
 
+
 class AlternatingRowFormatter(AlternatingRowFormatterMixin, Formatter):
     pass
 
+
 class StandaloneSortFormatter(
-    SortingFormatterMixin, StandaloneSortFormatterMixin, Formatter):
+        SortingFormatterMixin, StandaloneSortFormatterMixin, Formatter):
     pass
 
+
 class FormSortFormatter(FormSortFormatterMixin, Formatter):
     pass
 
+
 class StandaloneFullFormatter(
-    SortingFormatterMixin, StandaloneSortFormatterMixin,
-    AlternatingRowFormatterMixin, Formatter):
+        SortingFormatterMixin, StandaloneSortFormatterMixin,
+        AlternatingRowFormatterMixin, Formatter):
     pass
 
+
 class FormFullFormatter(
-    FormSortFormatterMixin, AlternatingRowFormatterMixin, Formatter):
+        FormSortFormatterMixin, AlternatingRowFormatterMixin, Formatter):
     pass
