@@ -15,7 +15,9 @@
 
 $Id: testing.py 2520 2005-06-27 21:26:18Z benji $
 """
-from zope import interface, component
+from zope import component
+from zope import interface
+
 import zc.table.interfaces
 import zc.table.table
 
@@ -27,7 +29,8 @@ class SimpleFormatter(zc.table.table.Formatter):
 def setUp(test):
     gsm = component.getGlobalSiteManager()
     gsm.registerUtility(SimpleFormatter, zc.table.interfaces.IFormatterFactory)
-    assert component.getUtility(zc.table.interfaces.IFormatterFactory) != None
+    assert component.getUtility(
+        zc.table.interfaces.IFormatterFactory) is not None
 
 
 def tearDown(test):
