@@ -11,16 +11,15 @@
 # FOR A PARTICULAR PURPOSE.
 #
 ##############################################################################
-"""
-
-$Id: tests.py 4428 2005-12-13 23:35:48Z gary $
-"""
+import doctest
 import unittest
-from zope import component
-from zope.component.testing import setUp, tearDown
+
+import zope.formlib.widgets
 import zope.publisher.interfaces.browser
 import zope.schema.interfaces
-import zope.formlib.widgets
+from zope import component
+from zope.component.testing import setUp
+from zope.component.testing import tearDown
 
 
 def columnSetUp(test):
@@ -65,20 +64,25 @@ def fieldColumnSetUp(test):
         zope.formlib.interfaces.IDisplayWidget)
 
 
+DOCTEST_FLAGS = (doctest.NORMALIZE_WHITESPACE |
+                 doctest.ELLIPSIS |
+                 doctest.IGNORE_EXCEPTION_DETAIL)
+
+
 def test_suite():
-    import doctest
     return unittest.TestSuite((
-        doctest.DocFileSuite('README.txt',
-            optionflags=doctest.NORMALIZE_WHITESPACE+doctest.ELLIPSIS,
-            ),
         doctest.DocFileSuite(
-            'column.txt',
+            'README.rst',
+            optionflags=DOCTEST_FLAGS,
+        ),
+        doctest.DocFileSuite(
+            'column.rst',
             setUp=columnSetUp, tearDown=tearDown,
-            optionflags=doctest.NORMALIZE_WHITESPACE+doctest.ELLIPSIS,
-            ),
+            optionflags=DOCTEST_FLAGS,
+        ),
         doctest.DocFileSuite(
-            'fieldcolumn.txt',
+            'fieldcolumn.rst',
             setUp=fieldColumnSetUp, tearDown=tearDown,
-            optionflags=doctest.NORMALIZE_WHITESPACE+doctest.ELLIPSIS,
-            ),
-        ))
+            optionflags=doctest.NORMALIZE_WHITESPACE | doctest.ELLIPSIS,
+        ),
+    ))
